@@ -10,8 +10,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/bin',
- 'BINLIBDEST': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
+ 'BINDIR': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/bin',
+ 'BINLIBDEST': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
  'BLDLIBRARY': '-L. -lpython3.9',
  'BLDSHARED': 'gcc -pthread -shared -m32 -m32',
  'BUILDEXE': '',
@@ -35,28 +35,28 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '-DNDEBUG -m32',
  'CONFIGURE_LDFLAGS': '-m32',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit' "
-                "'--enable-shared' '--with-ensurepip' "
-                "'--with-openssl=/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit' "
+ 'CONFIG_ARGS': "'--prefix=/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit' "
+                "'--enable-shared' '--with-ensurepip=install' "
+                "'--with-openssl=/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit' "
                 "'CC=gcc' 'CFLAGS=-O1 -g -m32' 'LDFLAGS=-m32' "
                 "'CPPFLAGS=-DNDEBUG -m32' "
-                "'PKG_CONFIG_PATH=/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit/lib64/pkgconfig:/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit/lib/pkgconfig:/opt/rh/python27/root/usr/lib64/pkgconfig'",
- 'CONFINCLUDEDIR': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include',
- 'CONFINCLUDEPY': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9',
+                "'PKG_CONFIG_PATH=/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit/lib64/pkgconfig:/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit/lib/pkgconfig:/opt/rh/python27/root/usr/lib64/pkgconfig'",
+ 'CONFINCLUDEDIR': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include',
+ 'CONFINCLUDEPY': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-export-1212627/Python-3.9.5/coverage.info',
- 'COVERAGE_REPORT': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-export-1212627/Python-3.9.5/lcov-report',
+ 'COVERAGE_INFO': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-export-1444150/Python-3.9.5/coverage.info',
+ 'COVERAGE_REPORT': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-export-1444150/Python-3.9.5/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -DNDEBUG -m32 -DNDEBUG -m32',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit '
-             '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib '
-             '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9 '
-             '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9/lib-dynload',
- 'DESTLIB': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
+ 'DESTDIRS': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit '
+             '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib '
+             '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9 '
+             '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -75,7 +75,7 @@ build_time_vars = {'ABIFLAGS': '',
  'DTRACE_OBJS': '',
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
- 'ENSUREPIP': 'upgrade',
+ 'ENSUREPIP': 'install',
  'EXE': '',
  'EXEMODE': 755,
  'EXPORTSFROM': '',
@@ -515,12 +515,12 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'i686-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include '
-                   '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include '
-                   '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9 '
-                   '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9',
- 'INCLUDEDIR': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include',
- 'INCLUDEPY': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9',
+ 'INCLDIRSTOMAKE': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include '
+                   '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include '
+                   '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9 '
+                   '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9',
+ 'INCLUDEDIR': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include',
+ 'INCLUDEPY': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/include/python3.9',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
@@ -537,14 +537,14 @@ build_time_vars = {'ABIFLAGS': '',
  'LDSHARED': 'gcc -pthread -shared -m32 -m32',
  'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
- 'LIBDIR': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib',
+ 'LIBDEST': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
+ 'LIBDIR': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib',
  'LIBFFI_INCLUDEDIR': '/usr/lib64/libffi-3.0.5/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/pkgconfig',
- 'LIBPL': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9/config-3.9-i386-linux-gnu',
+ 'LIBPC': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/pkgconfig',
+ 'LIBPL': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9/config-3.9-i386-linux-gnu',
  'LIBPYTHON': '',
  'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
@@ -562,13 +562,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
+ 'MACHDESTLIB': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/share/man',
+ 'MANDIR': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/share/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
@@ -594,8 +594,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit/include',
- 'OPENSSL_LDFLAGS': '-L/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit/lib',
+ 'OPENSSL_INCLUDES': '-I/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit/include',
+ 'OPENSSL_LDFLAGS': '-L/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
@@ -673,8 +673,8 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-export-1212627/Python-3.9.5:/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit/lib',
- 'SCRIPTDIR': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-export-1444150/Python-3.9.5:/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit/lib',
+ 'SCRIPTDIR': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
@@ -715,10 +715,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-export-1212627/Python-3.9.5:/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit/lib '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-export-1444150/Python-3.9.5:/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit/lib '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-export-1212627/Python-3.9.5:/var/lib/pb2/sb_1-4580984-1632455221.28/openssl-1.1.1l-linux-glibc2.12-32bit/lib '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-export-1444150/Python-3.9.5:/var/lib/pb2/sb_1-5451091-1638917762.37/openssl-1.1.1l-linux-glibc2.12-32bit/lib '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 'rt',
@@ -727,7 +727,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 1,
@@ -741,9 +741,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-export-1212627/Python-3.9.5',
- 'abs_srcdir': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-export-1212627/Python-3.9.5',
- 'datarootdir': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit/share',
- 'exec_prefix': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit',
- 'prefix': '/var/lib/pb2/sb_1-4580984-1632455221.28/Python-3.9.5-shell-linux-glibc2.12-32bit',
+ 'abs_builddir': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-export-1444150/Python-3.9.5',
+ 'abs_srcdir': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-export-1444150/Python-3.9.5',
+ 'datarootdir': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit/share',
+ 'exec_prefix': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit',
+ 'prefix': '/var/lib/pb2/sb_1-5451091-1638917762.37/Python-3.9.5-shell-linux-glibc2.12-32bit',
  'srcdir': '.'}
