@@ -75,6 +75,10 @@ class Gateway(object):
             The value to assign to the subnet_id property of this Gateway.
         :type subnet_id: str
 
+        :param network_security_group_ids:
+            The value to assign to the network_security_group_ids property of this Gateway.
+        :type network_security_group_ids: list[str]
+
         :param time_created:
             The value to assign to the time_created property of this Gateway.
         :type time_created: datetime
@@ -124,6 +128,7 @@ class Gateway(object):
             'compartment_id': 'str',
             'endpoint_type': 'str',
             'subnet_id': 'str',
+            'network_security_group_ids': 'list[str]',
             'time_created': 'datetime',
             'time_updated': 'datetime',
             'lifecycle_state': 'str',
@@ -142,6 +147,7 @@ class Gateway(object):
             'compartment_id': 'compartmentId',
             'endpoint_type': 'endpointType',
             'subnet_id': 'subnetId',
+            'network_security_group_ids': 'networkSecurityGroupIds',
             'time_created': 'timeCreated',
             'time_updated': 'timeUpdated',
             'lifecycle_state': 'lifecycleState',
@@ -159,6 +165,7 @@ class Gateway(object):
         self._compartment_id = None
         self._endpoint_type = None
         self._subnet_id = None
+        self._network_security_group_ids = None
         self._time_created = None
         self._time_updated = None
         self._lifecycle_state = None
@@ -324,6 +331,30 @@ class Gateway(object):
         """
         self._subnet_id = subnet_id
 
+    @property
+    def network_security_group_ids(self):
+        """
+        Gets the network_security_group_ids of this Gateway.
+        An array of Network Security Groups OCIDs associated with this API Gateway.
+
+
+        :return: The network_security_group_ids of this Gateway.
+        :rtype: list[str]
+        """
+        return self._network_security_group_ids
+
+    @network_security_group_ids.setter
+    def network_security_group_ids(self, network_security_group_ids):
+        """
+        Sets the network_security_group_ids of this Gateway.
+        An array of Network Security Groups OCIDs associated with this API Gateway.
+
+
+        :param network_security_group_ids: The network_security_group_ids of this Gateway.
+        :type: list[str]
+        """
+        self._network_security_group_ids = network_security_group_ids
+
     @property
     def time_created(self):
         """
