@@ -86,6 +86,10 @@ class Monitor(object):
             The value to assign to the repeat_interval_in_seconds property of this Monitor.
         :type repeat_interval_in_seconds: int
 
+        :param is_run_once:
+            The value to assign to the is_run_once property of this Monitor.
+        :type is_run_once: bool
+
         :param timeout_in_seconds:
             The value to assign to the timeout_in_seconds property of this Monitor.
         :type timeout_in_seconds: int
@@ -129,6 +133,7 @@ class Monitor(object):
             'script_name': 'str',
             'status': 'str',
             'repeat_interval_in_seconds': 'int',
+            'is_run_once': 'bool',
             'timeout_in_seconds': 'int',
             'target': 'str',
             'script_parameters': 'list[MonitorScriptParameterInfo]',
@@ -149,6 +154,7 @@ class Monitor(object):
             'script_name': 'scriptName',
             'status': 'status',
             'repeat_interval_in_seconds': 'repeatIntervalInSeconds',
+            'is_run_once': 'isRunOnce',
             'timeout_in_seconds': 'timeoutInSeconds',
             'target': 'target',
             'script_parameters': 'scriptParameters',
@@ -168,6 +174,7 @@ class Monitor(object):
         self._script_name = None
         self._status = None
         self._repeat_interval_in_seconds = None
+        self._is_run_once = None
         self._timeout_in_seconds = None
         self._target = None
         self._script_parameters = None
@@ -417,6 +424,30 @@ class Monitor(object):
         """
         self._repeat_interval_in_seconds = repeat_interval_in_seconds
 
+    @property
+    def is_run_once(self):
+        """
+        **[Required]** Gets the is_run_once of this Monitor.
+        If runOnce is enabled, then the monitor will run once.
+
+
+        :return: The is_run_once of this Monitor.
+        :rtype: bool
+        """
+        return self._is_run_once
+
+    @is_run_once.setter
+    def is_run_once(self, is_run_once):
+        """
+        Sets the is_run_once of this Monitor.
+        If runOnce is enabled, then the monitor will run once.
+
+
+        :param is_run_once: The is_run_once of this Monitor.
+        :type: bool
+        """
+        self._is_run_once = is_run_once
+
     @property
     def timeout_in_seconds(self):
         """
