@@ -242,7 +242,7 @@ class CreateAutonomousContainerDatabaseDetails(object):
     def db_unique_name(self):
         """
         Gets the db_unique_name of this CreateAutonomousContainerDatabaseDetails.
-        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.
+        **Deprecated.** The `DB_UNIQUE_NAME` value is set by Oracle Cloud Infrastructure.  Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
 
 
         :return: The db_unique_name of this CreateAutonomousContainerDatabaseDetails.
@@ -254,7 +254,7 @@ class CreateAutonomousContainerDatabaseDetails(object):
     def db_unique_name(self, db_unique_name):
         """
         Sets the db_unique_name of this CreateAutonomousContainerDatabaseDetails.
-        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.
+        **Deprecated.** The `DB_UNIQUE_NAME` value is set by Oracle Cloud Infrastructure.  Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
 
 
         :param db_unique_name: The db_unique_name of this CreateAutonomousContainerDatabaseDetails.
@@ -488,7 +488,7 @@ class CreateAutonomousContainerDatabaseDetails(object):
     def peer_db_unique_name(self):
         """
         Gets the peer_db_unique_name of this CreateAutonomousContainerDatabaseDetails.
-        The `DB_UNIQUE_NAME` of the peer Autonomous Container Database in a Data Guard association.
+        **Deprecated.** The `DB_UNIQUE_NAME` of the peer Autonomous Container Database in a Data Guard association is set by Oracle Cloud Infrastructure.  Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
 
 
         :return: The peer_db_unique_name of this CreateAutonomousContainerDatabaseDetails.
@@ -500,7 +500,7 @@ class CreateAutonomousContainerDatabaseDetails(object):
     def peer_db_unique_name(self, peer_db_unique_name):
         """
         Sets the peer_db_unique_name of this CreateAutonomousContainerDatabaseDetails.
-        The `DB_UNIQUE_NAME` of the peer Autonomous Container Database in a Data Guard association.
+        **Deprecated.** The `DB_UNIQUE_NAME` of the peer Autonomous Container Database in a Data Guard association is set by Oracle Cloud Infrastructure.  Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
 
 
         :param peer_db_unique_name: The peer_db_unique_name of this CreateAutonomousContainerDatabaseDetails.
