@@ -23,6 +23,88 @@ class DashxApisClientCompositeOperations(object):
         """
         self.client = client
 
+    def change_management_dashboards_compartment_and_wait_for_state(self, management_dashboard_id, change_management_dashboards_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
+        """
+        Calls :py:func:`~oci.management_dashboard.DashxApisClient.change_management_dashboards_compartment` and waits for the :py:class:`~oci.management_dashboard.models.ManagementDashboard` acted upon
+        to enter the given state(s).
+
+        :param str management_dashboard_id: (required)
+            A unique dashboard identifier.
+
+        :param oci.management_dashboard.models.ChangeManagementDashboardsCompartmentDetails change_management_dashboards_compartment_details: (required)
+            ID of the dashboard that is being moved.
+
+        :param list[str] wait_for_states:
+            An array of states to wait on. These should be valid values for :py:attr:`~oci.management_dashboard.models.ManagementDashboard.lifecycle_state`
+
+        :param dict operation_kwargs:
+            A dictionary of keyword arguments to pass to :py:func:`~oci.management_dashboard.DashxApisClient.change_management_dashboards_compartment`
+
+        :param dict waiter_kwargs:
+            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
+            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
+        """
+        operation_result = self.client.change_management_dashboards_compartment(management_dashboard_id, change_management_dashboards_compartment_details, **operation_kwargs)
+        if not wait_for_states:
+            return operation_result
+
+        lowered_wait_for_states = [w.lower() for w in wait_for_states]
+        wait_for_resource_id = operation_result.data.id
+
+        try:
+            waiter_result = oci.wait_until(
+                self.client,
+                self.client.get_management_dashboard(wait_for_resource_id),
+                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
+                **waiter_kwargs
+            )
+            result_to_return = waiter_result
+
+            return result_to_return
+        except Exception as e:
+            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)
+
+    def change_management_saved_searches_compartment_and_wait_for_state(self, management_saved_search_id, change_management_saved_searches_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
+        """
+        Calls :py:func:`~oci.management_dashboard.DashxApisClient.change_management_saved_searches_compartment` and waits for the :py:class:`~oci.management_dashboard.models.ManagementSavedSearch` acted upon
+        to enter the given state(s).
+
+        :param str management_saved_search_id: (required)
+            A unique saved search identifier.
+
+        :param oci.management_dashboard.models.ChangeManagementSavedSearchesCompartmentDetails change_management_saved_searches_compartment_details: (required)
+            ID of the saved search that is being moved.
+
+        :param list[str] wait_for_states:
+            An array of states to wait on. These should be valid values for :py:attr:`~oci.management_dashboard.models.ManagementSavedSearch.lifecycle_state`
+
+        :param dict operation_kwargs:
+            A dictionary of keyword arguments to pass to :py:func:`~oci.management_dashboard.DashxApisClient.change_management_saved_searches_compartment`
+
+        :param dict waiter_kwargs:
+            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
+            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
+        """
+        operation_result = self.client.change_management_saved_searches_compartment(management_saved_search_id, change_management_saved_searches_compartment_details, **operation_kwargs)
+        if not wait_for_states:
+            return operation_result
+
+        lowered_wait_for_states = [w.lower() for w in wait_for_states]
+        wait_for_resource_id = operation_result.data.id
+
+        try:
+            waiter_result = oci.wait_until(
+                self.client,
+                self.client.get_management_saved_search(wait_for_resource_id),
+                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
+                **waiter_kwargs
+            )
+            result_to_return = waiter_result
+
+            return result_to_return
+        except Exception as e:
+            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)
+
     def create_management_dashboard_and_wait_for_state(self, create_management_dashboard_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
         """
         Calls :py:func:`~oci.management_dashboard.DashxApisClient.create_management_dashboard` and waits for the :py:class:`~oci.management_dashboard.models.ManagementDashboard` acted upon
